import ons_metadata_validation.validation.back_office_validations as bov
import ons_metadata_validation.validation.codes_and_values_validations as cavv
import ons_metadata_validation.validation.dataset_file_validations as dfv
import ons_metadata_validation.validation.dataset_resource_validations as drv
import ons_metadata_validation.validation.dataset_series_validations as dsv
import ons_metadata_validation.validation.variables_validations as vv

V2_TEMPLATE = {
    "DatasetResource_dataset_resource_name": {
        "tab": "Dataset Resource",
        "name": "Dataset Resource Name",
        "ref_cell": "C6",
        "value_col": "F",
        "column": False,
        "row_start": 6,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_dataset_resource_name,
    },
    "DatasetResource_acronym": {
        "tab": "Dataset Resource",
        "name": "Acronym",
        "ref_cell": "C7",
        "value_col": "F",
        "column": False,
        "row_start": 7,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_acronym,
    },
    "DatasetResource_significant_changes": {
        "tab": "Dataset Resource",
        "name": "Significant Changes",
        "ref_cell": "C8",
        "value_col": "F",
        "column": False,
        "row_start": 8,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_significant_changes,
    },
    "DatasetResource_data_creator": {
        "tab": "Dataset Resource",
        "name": "Data Creator",
        "ref_cell": "C9",
        "value_col": "F",
        "column": False,
        "row_start": 9,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_data_creator,
    },
    "DatasetResource_data_contributor_s": {
        "tab": "Dataset Resource",
        "name": "Data Contributor(s)",
        "ref_cell": "C10",
        "value_col": "F",
        "column": False,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_data_contributors,
    },
    "DatasetResource_purpose_of_this_dataset_resource": {
        "tab": "Dataset Resource",
        "name": "Purpose of this Dataset Resource",
        "ref_cell": "C11",
        "value_col": "F",
        "column": False,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_purpose_of_this_dataset_resource,
    },
    "DatasetResource_search_keywords": {
        "tab": "Dataset Resource",
        "name": "Search keywords",
        "ref_cell": "C12",
        "value_col": "F",
        "column": False,
        "row_start": 12,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_search_keywords,
    },
    "DatasetResource_dataset_theme": {
        "tab": "Dataset Resource",
        "name": "Dataset Theme",
        "ref_cell": "C13",
        "value_col": "F",
        "column": False,
        "row_start": 13,
        "mandatory": True,
        "enum": [
            "Business and economy",
            "Crime and justice",
            "Defence",
            "Education",
            "Environment",
            "Government",
            "Government spending",
            "Health",
            "Mapping",
            "Society",
            "Towns and cities",
            "Transport",
            "Digital service performance",
            "Government reference data",
        ],
        "datatype": str,
        "func": drv.validate_DatasetResource_dataset_theme,
    },
    "DatasetResource_geographic_level": {
        "tab": "Dataset Resource",
        "name": "Geographic Level",
        "ref_cell": "C14",
        "value_col": "F",
        "column": False,
        "row_start": 14,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_geographic_level,
    },
    "DatasetResource_provenance": {
        "tab": "Dataset Resource",
        "name": "Provenance",
        "ref_cell": "C15",
        "value_col": "F",
        "column": False,
        "row_start": 15,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_provenance,
    },
    "DatasetResource_number_of_dataset_series": {
        "tab": "Dataset Resource",
        "name": "Number of Dataset Series",
        "ref_cell": "C18",
        "value_col": "F",
        "column": False,
        "row_start": 18,
        "mandatory": True,
        "enum": [],
        "datatype": int,
        "func": drv.validate_DatasetResource_number_of_dataset_series,
    },
    "DatasetResource_number_of_structural_data_files": {
        "tab": "Dataset Resource",
        "name": "Number of structural data files",
        "ref_cell": "C19",
        "value_col": "F",
        "column": False,
        "row_start": 19,
        "mandatory": True,
        "enum": [],
        "datatype": int,
        "func": drv.validate_DatasetResource_number_of_structural_data_files,
    },
    "DatasetResource_date_of_completion": {
        "tab": "Dataset Resource",
        "name": "Date of completion",
        "ref_cell": "C20",
        "value_col": "F",
        "column": False,
        "row_start": 20,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_date_of_completion,
    },
    "DatasetResource_name_and_email_of_individual_completing_this_template": {
        "tab": "Dataset Resource",
        "name": "Name and email of individual completing this template",
        "ref_cell": "C21",
        "value_col": "F",
        "column": False,
        "row_start": 21,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": drv.validate_DatasetResource_name_and_email_of_individual_completing_this_template,
    },
    "DatasetResource_security_classification": {
        "tab": "Dataset Resource",
        "name": "Security Classification",
        "ref_cell": "C24",
        "value_col": "F",
        "column": False,
        "row_start": 24,
        "mandatory": True,
        "enum": [
            "Official",
            "Official-Sensitive",
            "Secret",
            "Top Secret",
            "Non-Applicable",
        ],
        "datatype": str,
        "func": drv.validate_DatasetResource_security_classification,
    },
    "DatasetResource_dataset_resource_type": {
        "tab": "Dataset Resource",
        "name": "Dataset Resource type",
        "ref_cell": "C25",
        "value_col": "F",
        "column": False,
        "row_start": 25,
        "mandatory": True,
        "enum": [
            "Dataset Series",
            "Longitudinal",
            "Survey",
            "Statistical Output - Experimental",
            "Statistical Output - Key",
            "Statistical Output - National",
            "Reference",
            "Code List",
            "Administrative",
        ],
        "datatype": str,
        "func": drv.validate_DatasetResource_dataset_resource_type,
    },
    "DatasetResource_number_of_non_structural_reference_files": {
        "tab": "Dataset Resource",
        "name": "Number of non-structural/reference files ",
        "ref_cell": "C26",
        "value_col": "F",
        "column": False,
        "row_start": 26,
        "mandatory": True,
        "enum": [],
        "datatype": int,
        "func": drv.validate_DatasetResource_number_of_non_structural_reference_files,
    },
    "DatasetResource_number_of_code_list_files": {
        "tab": "Dataset Resource",
        "name": "Number of code list files",
        "ref_cell": "C27",
        "value_col": "F",
        "column": False,
        "row_start": 27,
        "mandatory": True,
        "enum": [],
        "datatype": int,
        "func": drv.validate_DatasetResource_number_of_code_list_files,
    },
    "DatasetSeries_dataset_series_name": {
        "tab": "Dataset Series",
        "name": "Dataset Series Name",
        "ref_cell": "C7",
        "value_col": "C",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_dataset_series_name,
    },
    "DatasetSeries_google_cloud_platform_bigquery_table_name": {
        "tab": "Dataset Series",
        "name": "Google Cloud Platform BigQuery Table Name",
        "ref_cell": "D7",
        "value_col": "D",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_google_cloud_platform_bigquery_table_name,
    },
    "DatasetSeries_description": {
        "tab": "Dataset Series",
        "name": "Description",
        "ref_cell": "E7",
        "value_col": "E",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_description,
    },
    "DatasetSeries_reference_period": {
        "tab": "Dataset Series",
        "name": "Reference Period",
        "ref_cell": "F7",
        "value_col": "F",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_reference_period,
    },
    "DatasetSeries_geographic_coverage": {
        "tab": "Dataset Series",
        "name": "Geographic Coverage",
        "ref_cell": "G7",
        "value_col": "G",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_geographic_coverage,
    },
    "DatasetSeries_frequency": {
        "tab": "Dataset Series",
        "name": "Frequency",
        "ref_cell": "H7",
        "value_col": "H",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [
            "Annual",
            "Biennial",
            "Bimonthly",
            "Biweekly",
            "Continuous",
            "Daily",
            "Historical",
            "Irregular",
            "Monthly",
            "Periodic",
            "Quarterly",
            "Real Time",
            "Semiannual",
            "Semimonthly",
            "Semiweekly",
            "Single",
            "Three times a month",
            "Three times a week",
            "Three times a year",
            "Triennial",
            "Weekly",
        ],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_frequency,
    },
    "DatasetSeries_supply_type": {
        "tab": "Dataset Series",
        "name": "Supply Type",
        "ref_cell": "I7",
        "value_col": "I",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": ["Full ", "Append"],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_supply_type,
    },
    "DatasetSeries_wave_number_time_period_covered_survey_only": {
        "tab": "Dataset Series",
        "name": "Wave number/time period covered (Survey only)",
        "ref_cell": "J7",
        "value_col": "J",
        "column": True,
        "row_start": 11,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_wave_numbertime_period_covered_survey_only,
    },
    "DatasetSeries_links_to_online_documentation_and_other_useful_materials": {
        "tab": "Dataset Series",
        "name": "Links to online documentation and other useful materials",
        "ref_cell": "K7",
        "value_col": "K",
        "column": True,
        "row_start": 11,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": dsv.validate_DatasetSeries_links_to_online_documentation_and_other_useful_materials,
    },
    "DatasetFile_google_cloud_platform_bigquery_table_name": {
        "tab": "Dataset File",
        "name": "Google Cloud Platform BigQuery Table Name",
        "ref_cell": "C7",
        "value_col": "C",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_google_cloud_platform_bigquery_table_name,
    },
    "DatasetFile_file_path_and_name": {
        "tab": "Dataset File",
        "name": "File path and name",
        "ref_cell": "D7",
        "value_col": "D",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_file_path_and_name,
    },
    "DatasetFile_file_format": {
        "tab": "Dataset File",
        "name": "File Format",
        "ref_cell": "E7",
        "value_col": "E",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": ["CSV", "JSON", "PARQUET", "JSON Multi-Line"],
        "datatype": str,
        "func": dfv.validate_DatasetFile_file_format,
    },
    "DatasetFile_column_seperator": {
        "tab": "Dataset File",
        "name": "Column Seperator",
        "ref_cell": "F7",
        "value_col": "F",
        "column": True,
        "row_start": 11,
        "mandatory": False,
        "enum": [",", "|", "\\t"],
        "datatype": str,
        "func": dfv.validate_DatasetFile_column_seperator,
    },
    "DatasetFile_string_identifier": {
        "tab": "Dataset File",
        "name": "String identifier",
        "ref_cell": "G7",
        "value_col": "G",
        "column": True,
        "row_start": 11,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_string_identifier,
    },
    "DatasetFile_file_description": {
        "tab": "Dataset File",
        "name": "File description",
        "ref_cell": "H7",
        "value_col": "H",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_file_description,
    },
    "DatasetFile_reference_period": {
        "tab": "Dataset File",
        "name": "Reference period",
        "ref_cell": "I7",
        "value_col": "I",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_reference_period,
    },
    "DatasetFile_file_size": {
        "tab": "Dataset File",
        "name": "File size",
        "ref_cell": "J7",
        "value_col": "J",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": float,
        "func": dfv.validate_DatasetFile_file_size,
    },
    "DatasetFile_file_size_unit": {
        "tab": "Dataset File",
        "name": "File size unit",
        "ref_cell": "K7",
        "value_col": "K",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_file_size_unit,
    },
    "DatasetFile_is_code_list": {
        "tab": "Dataset File",
        "name": "Is code list",
        "ref_cell": "L7",
        "value_col": "L",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_is_code_list,
    },
    "DatasetFile_number_of_records": {
        "tab": "Dataset File",
        "name": "Number of records",
        "ref_cell": "M7",
        "value_col": "M",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": int,
        "func": dfv.validate_DatasetFile_number_of_records,
    },
    "DatasetFile_is_this_file_one_of_a_sequence_to_be_appended_back_together": {
        "tab": "Dataset File",
        "name": "Is this file one of a sequence to be appended back together?",
        "ref_cell": "N7",
        "value_col": "N",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": ["Yes", "No"],
        "datatype": str,
        "func": dfv.validate_DatasetFile_is_this_file_one_of_a_sequence_to_be_appended_back_together,
    },
    "DatasetFile_number_of_header_rows": {
        "tab": "Dataset File",
        "name": "Number of header rows",
        "ref_cell": "O7",
        "value_col": "O",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": int,
        "func": dfv.validate_DatasetFile_number_of_header_rows,
    },
    "DatasetFile_number_of_footer_rows": {
        "tab": "Dataset File",
        "name": "Number of footer rows",
        "ref_cell": "P7",
        "value_col": "P",
        "column": True,
        "row_start": 11,
        "mandatory": True,
        "enum": [],
        "datatype": int,
        "func": dfv.validate_DatasetFile_number_of_footer_rows,
    },
    "DatasetFile_character_encoding": {
        "tab": "Dataset File",
        "name": "Character encoding",
        "ref_cell": "Q7",
        "value_col": "Q",
        "column": True,
        "row_start": 11,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_character_encoding,
    },
    "DatasetFile_hash_value_for_checksum": {
        "tab": "Dataset File",
        "name": "Hash value for checksum",
        "ref_cell": "R7",
        "value_col": "R",
        "column": True,
        "row_start": 11,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_hash_value_for_checksum,
    },
    "DatasetFile_notes": {
        "tab": "Dataset File",
        "name": "Notes",
        "ref_cell": "S7",
        "value_col": "S",
        "column": True,
        "row_start": 11,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": dfv.validate_DatasetFile_notes,
    },
    "Variables_google_cloud_platform_bigquery_table_name": {
        "tab": "Variables",
        "name": "Google Cloud Platform BigQuery Table Name",
        "ref_cell": "C6",
        "value_col": "C",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_google_cloud_platform_bigquery_table_name,
    },
    "Variables_variable_name": {
        "tab": "Variables",
        "name": "Variable name",
        "ref_cell": "D6",
        "value_col": "D",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_variable_name,
    },
    "Variables_google_cloud_platform_compatible_variable_name": {
        "tab": "Variables",
        "name": "Google Cloud Platform compatible variable name",
        "ref_cell": "E6",
        "value_col": "E",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_google_cloud_platform_compatible_variable_name,
    },
    "Variables_variable_label": {
        "tab": "Variables",
        "name": "Variable label",
        "ref_cell": "F6",
        "value_col": "F",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_variable_label,
    },
    "Variables_variable_description": {
        "tab": "Variables",
        "name": "Variable description",
        "ref_cell": "G6",
        "value_col": "G",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_variable_description,
    },
    "Variables_position_in_file": {
        "tab": "Variables",
        "name": "Position in file",
        "ref_cell": "H6",
        "value_col": "H",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": int,
        "func": vv.validate_Variables_position_in_file,
    },
    "Variables_personally_identifiable_information": {
        "tab": "Variables",
        "name": "Personally Identifiable Information",
        "ref_cell": "I6",
        "value_col": "I",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_personally_identifiable_information,
    },
    "Variables_variable_data_type": {
        "tab": "Variables",
        "name": "Variable Data Type",
        "ref_cell": "J6",
        "value_col": "J",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [
            "ARRAY",
            "BIGINT",
            "BIT",
            "BOOLEAN",
            "CHAR",
            "DATE",
            "DATETIME",
            "DECIMAL",
            "DOUBLE",
            "FLOAT",
            "INT",
            "INT16",
            "INT32",
            "INT8",
            "INTEGER",
            "LONG",
            "NUMBER",
            "NUMERIC",
            "REAL",
            "SHORTTEXT",
            "SMALLINT",
            "STRING",
            "TEXT",
            "TIME",
            "TIMESTAMP",
            "TINYINT",
        ],
        "datatype": str,
        "func": vv.validate_Variables_variable_data_type,
    },
    "Variables_gcp_data_type": {
        "tab": "Variables",
        "name": "GCP Data Type",
        "ref_cell": "K6",
        "value_col": "K",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [
            "ARRAY",
            "BIGNUMBER",
            "BOOL",
            "DATE",
            "FLOAT64",
            "INT64",
            "INTERVAL",
            "STRING",
            "TIME",
            "TIMESTAMP",
        ],
        "datatype": str,
        "func": vv.validate_Variables_gcp_data_type,
    },
    "Variables_variable_length_precision": {
        "tab": "Variables",
        "name": "Variable length/precision",
        "ref_cell": "L6",
        "value_col": "L",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_variable_length_precision,
    },
    "Variables_variable_format": {
        "tab": "Variables",
        "name": "Variable format",
        "ref_cell": "M6",
        "value_col": "M",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_variable_format,
    },
    "Variables_is_primary_key": {
        "tab": "Variables",
        "name": "Is Primary Key",
        "ref_cell": "N6",
        "value_col": "N",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_is_primary_key,
    },
    "Variables_is_foreign_key": {
        "tab": "Variables",
        "name": "Is Foreign Key",
        "ref_cell": "O6",
        "value_col": "O",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_is_foreign_key,
    },
    "Variables_foreign_key_file_name": {
        "tab": "Variables",
        "name": "Foreign Key file name",
        "ref_cell": "P6",
        "value_col": "P",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_foreign_key_file_name,
    },
    "Variables_foreign_key_variable_name": {
        "tab": "Variables",
        "name": "Foreign Key variable name",
        "ref_cell": "Q6",
        "value_col": "Q",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_foreign_key_variable_name,
    },
    "Variables_nullability": {
        "tab": "Variables",
        "name": "Nullability",
        "ref_cell": "R6",
        "value_col": "R",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": ["NULL", "NOT NULL"],
        "datatype": str,
        "func": vv.validate_Variables_nullability,
    },
    "Variables_null_values_denoted_by": {
        "tab": "Variables",
        "name": "Null values denoted by",
        "ref_cell": "S6",
        "value_col": "S",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_null_values_denoted_by,
    },
    "Variables_variable_constraints": {
        "tab": "Variables",
        "name": "Variable constraints",
        "ref_cell": "T6",
        "value_col": "T",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_variable_constraints,
    },
    "Variables_applicable_business_rules": {
        "tab": "Variables",
        "name": "Applicable business rules",
        "ref_cell": "U6",
        "value_col": "U",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_applicable_business_rules,
    },
    "Variables_is_this_a_code": {
        "tab": "Variables",
        "name": "Is this a code?",
        "ref_cell": "V6",
        "value_col": "V",
        "column": True,
        "row_start": 10,
        "mandatory": True,
        "enum": ["Yes", "No"],
        "datatype": str,
        "func": vv.validate_Variables_is_this_a_code,
    },
    "Variables_notes": {
        "tab": "Variables",
        "name": "Notes",
        "ref_cell": "W6",
        "value_col": "W",
        "column": True,
        "row_start": 10,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": vv.validate_Variables_notes,
    },
    "CodesandValues_google_cloud_platform_bigquery_table_name": {
        "tab": "Codes and Values",
        "name": "Google Cloud Platform BigQuery Table Name",
        "ref_cell": "C5",
        "value_col": "C",
        "column": True,
        "row_start": 8,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": cavv.validate_CodesandValues_google_cloud_platform_bigquery_table_name,
    },
    "CodesandValues_variable_name": {
        "tab": "Codes and Values",
        "name": "Variable name",
        "ref_cell": "D5",
        "value_col": "D",
        "column": True,
        "row_start": 8,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": cavv.validate_CodesandValues_variable_name,
    },
    "CodesandValues_key": {
        "tab": "Codes and Values",
        "name": "Key",
        "ref_cell": "E5",
        "value_col": "E",
        "column": True,
        "row_start": 8,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": cavv.validate_CodesandValues_key,
    },
    "CodesandValues_value": {
        "tab": "Codes and Values",
        "name": "Value",
        "ref_cell": "F5",
        "value_col": "F",
        "column": True,
        "row_start": 8,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": cavv.validate_CodesandValues_value,
    },
    "CodesandValues_notes": {
        "tab": "Codes and Values",
        "name": "Notes",
        "ref_cell": "G5",
        "value_col": "G",
        "column": True,
        "row_start": 8,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": cavv.validate_CodesandValues_notes,
    },
    "BackOffice_ids_business_catalogue_identifier": {
        "tab": "Back Office",
        "name": "IDS Business Catalogue Identifier",
        "ref_cell": "C14",
        "value_col": "F",
        "column": False,
        "row_start": 14,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_ids_business_catalogue_identifier,
    },
    "BackOffice_description": {
        "tab": "Back Office",
        "name": "Description",
        "ref_cell": "C15",
        "value_col": "F",
        "column": False,
        "row_start": 15,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_description,
    },
    "BackOffice_abstract": {
        "tab": "Back Office",
        "name": "Abstract",
        "ref_cell": "C16",
        "value_col": "F",
        "column": False,
        "row_start": 16,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_abstract,
    },
    "BackOffice_google_cloud_platform_project_name": {
        "tab": "Back Office",
        "name": "Google Cloud Platform Project name",
        "ref_cell": "C17",
        "value_col": "F",
        "column": False,
        "row_start": 17,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_google_cloud_platform_project_name,
    },
    "BackOffice_google_cloud_platform_big_query_dataset_name": {
        "tab": "Back Office",
        "name": "Google Cloud Platform Big Query Dataset name",
        "ref_cell": "C18",
        "value_col": "F",
        "column": False,
        "row_start": 18,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_google_cloud_platform_big_query_dataset_name,
    },
    "BackOffice_other_unique_identifier_s_for_dataset_resource": {
        "tab": "Back Office",
        "name": "Other Unique Identifier(s) for Dataset Resource",
        "ref_cell": "C19",
        "value_col": "F",
        "column": False,
        "row_start": 19,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_other_unique_identifiers_for_dataset_resource,
    },
    "BackOffice_frequency": {
        "tab": "Back Office",
        "name": "Frequency ",
        "ref_cell": "C20",
        "value_col": "F",
        "column": False,
        "row_start": 20,
        "mandatory": False,
        "enum": [
            "Annual",
            "Biennial",
            "Bimonthly",
            "Biweekly",
            "Continuous",
            "Daily",
            "Historical",
            "Irregular",
            "Monthly",
            "Periodic",
            "Quarterly",
            "Real Time",
            "Semiannual",
            "Semimonthly",
            "Semiweekly",
            "Single",
            "Three times a month",
            "Three times a week",
            "Three times a year",
            "Triennial",
            "Weekly",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_frequency_,
    },
    "BackOffice_geographic_coverage": {
        "tab": "Back Office",
        "name": "Geographic Coverage",
        "ref_cell": "C21",
        "value_col": "F",
        "column": False,
        "row_start": 21,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_geographic_coverage,
    },
    "BackOffice_temporal_coverage": {
        "tab": "Back Office",
        "name": "Temporal Coverage",
        "ref_cell": "C22",
        "value_col": "F",
        "column": False,
        "row_start": 22,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_temporal_coverage,
    },
    "BackOffice_sensitivity_status_for_dataset_resource": {
        "tab": "Back Office",
        "name": "Sensitivity status for Dataset Resource",
        "ref_cell": "C23",
        "value_col": "F",
        "column": False,
        "row_start": 23,
        "mandatory": True,
        "enum": ["Low", "Medium", "High"],
        "datatype": str,
        "func": bov.validate_BackOffice_sensitivity_status_for_dataset_resource,
    },
    "BackOffice_sensitivity_tool_url": {
        "tab": "Back Office",
        "name": "Sensitivity tool URL",
        "ref_cell": "C24",
        "value_col": "F",
        "column": False,
        "row_start": 24,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_sensitivity_tool_url,
    },
    "BackOffice_retention_date": {
        "tab": "Back Office",
        "name": "Retention Date",
        "ref_cell": "C25",
        "value_col": "F",
        "column": False,
        "row_start": 25,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_retention_date,
    },
    "BackOffice_provider_statement_for_retention_removal_or_deletion": {
        "tab": "Back Office",
        "name": "Provider statement for retention, removal or deletion",
        "ref_cell": "C26",
        "value_col": "F",
        "column": False,
        "row_start": 26,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_provider_statement_for_retention_removal_or_deletion,
    },
    "BackOffice_removal_date": {
        "tab": "Back Office",
        "name": "Removal Date",
        "ref_cell": "C27",
        "value_col": "F",
        "column": False,
        "row_start": 27,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_removal_date,
    },
    "BackOffice_removal_comments": {
        "tab": "Back Office",
        "name": "Removal Comments",
        "ref_cell": "C28",
        "value_col": "F",
        "column": False,
        "row_start": 28,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_removal_comments,
    },
    "BackOffice_data_controller": {
        "tab": "Back Office",
        "name": "Data Controller",
        "ref_cell": "C29",
        "value_col": "F",
        "column": False,
        "row_start": 29,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_data_controller,
    },
    "BackOffice_data_processor": {
        "tab": "Back Office",
        "name": "Data Processor",
        "ref_cell": "C30",
        "value_col": "F",
        "column": False,
        "row_start": 30,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_data_processor,
    },
    "BackOffice_dataset_domain": {
        "tab": "Back Office",
        "name": "Dataset Domain",
        "ref_cell": "C31",
        "value_col": "F",
        "column": False,
        "row_start": 31,
        "mandatory": True,
        "enum": [
            "Crime and Justice",
            "Economics",
            "Government finance, Fiscal and Public Sector finances",
            "Human settlements and housing",
            "Income and Consumption",
            "Education ",
            "Health ",
            "Labour",
            "Population and Migration",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_dataset_domain,
    },
    "BackOffice_legal_gateway": {
        "tab": "Back Office",
        "name": "Legal Gateway",
        "ref_cell": "C32",
        "value_col": "F",
        "column": False,
        "row_start": 32,
        "mandatory": False,
        "enum": [
            "Digital Economy Act 2017",
            "Statistics and Registration Service Act 2007",
            "NHS Act 2006",
            "NHS Act 2006 with COPI Regulations 2002, Reg 3(4)",
            "Health and Social Care Act 2012",
            "Education Act 1996 / 2011",
            "Education and Skills Act 2008",
            "Children's Act 1989",
            "Legal Gateway Not Required",
            "Other",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_legal_gateway,
    },
    "BackOffice_other_legal_gateway": {
        "tab": "Back Office",
        "name": "Other Legal Gateway",
        "ref_cell": "C33",
        "value_col": "F",
        "column": False,
        "row_start": 33,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_other_legal_gateway,
    },
    "BackOffice_licensing_status": {
        "tab": "Back Office",
        "name": "Licensing status",
        "ref_cell": "C34",
        "value_col": "F",
        "column": False,
        "row_start": 34,
        "mandatory": False,
        "enum": [
            "Open Data Commons Open Database License (ODbL)",
            "Open Government Licence v3.0",
            "Open Government Licence v2.0",
            "Open Government Licence v1.0",
            "Statistics and Registration Service Act 2007",
            "Non-Commercial Government Licence v2.0",
            "Non-Commercial Government Licence v1.0",
            "Developer Licence 2.0",
            "Developer Licence 1.0",
            "Charged Licence",
            "Open Supreme Court Licence",
            "Restricted",
            "Memorandum of Understanding (MoU)",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_licensing_status,
    },
    "BackOffice_metadata_access": {
        "tab": "Back Office",
        "name": "Metadata Access",
        "ref_cell": "C35",
        "value_col": "F",
        "column": False,
        "row_start": 35,
        "mandatory": True,
        "enum": [
            "Publish to Website & Hub",
            "Publish to Hub only",
            "Do not publish",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_metadata_access,
    },
    "BackOffice_documentation": {
        "tab": "Back Office",
        "name": "Documentation",
        "ref_cell": "C36",
        "value_col": "F",
        "column": False,
        "row_start": 36,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_documentation,
    },
    "BackOffice_what_are_the_linkage_requirements_for_the_data_within_the_project_scope": {
        "tab": "Back Office",
        "name": "What are the linkage requirements for the data within the project scope?",
        "ref_cell": "C37",
        "value_col": "F",
        "column": False,
        "row_start": 37,
        "mandatory": True,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_what_are_the_linkage_requirements_for_the_data_within_the_project_scope,
    },
    "BackOffice_how_has_deidentification_been_achieved": {
        "tab": "Back Office",
        "name": "How has deidentification been achieved?",
        "ref_cell": "C38",
        "value_col": "F",
        "column": False,
        "row_start": 38,
        "mandatory": False,
        "enum": [],
        "datatype": str,
        "func": bov.validate_BackOffice_how_has_deidentification_been_achieved,
    },
    "BackOffice_should_this_dataset_be_visible_for_internal_or_external_users": {
        "tab": "Back Office",
        "name": "Should this dataset be visible for internal or external users?",
        "ref_cell": "C39",
        "value_col": "F",
        "column": False,
        "row_start": 39,
        "mandatory": True,
        "enum": ["Internal only", "Internal and External"],
        "datatype": str,
        "func": bov.validate_BackOffice_should_this_dataset_be_visible_for_internal_or_external_users,
    },
    "BackOffice_restrictions_for_access": {
        "tab": "Back Office",
        "name": "Restrictions for Access",
        "ref_cell": "C40",
        "value_col": "F",
        "column": False,
        "row_start": 40,
        "mandatory": True,
        "enum": [
            "Access for all accredited researchers",
            "Access limited to specific researchers",
            "Limited to specific individuals",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_restrictions_for_access,
    },
    "BackOffice_research_outputs": {
        "tab": "Back Office",
        "name": "Research Outputs",
        "ref_cell": "C41",
        "value_col": "F",
        "column": False,
        "row_start": 41,
        "mandatory": True,
        "enum": [
            "Research outputs must be sent to the data owner",
            "Research outputs must be approved by the data owner",
            "No requirements",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_research_outputs,
    },
    "BackOffice_project_approval": {
        "tab": "Back Office",
        "name": "Project Approval",
        "ref_cell": "C42",
        "value_col": "F",
        "column": False,
        "row_start": 42,
        "mandatory": True,
        "enum": [
            "Projects must be accredited and have approval from the data owner",
            "Projects must be accredited",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_project_approval,
    },
    "BackOffice_disclosure_control": {
        "tab": "Back Office",
        "name": "Disclosure Control",
        "ref_cell": "C43",
        "value_col": "F",
        "column": False,
        "row_start": 43,
        "mandatory": True,
        "enum": [
            "Standard disclosure rules apply",
            "Bespoke disclosure rules apply",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_disclosure_control,
    },
    "BackOffice_research_disclaimer": {
        "tab": "Back Office",
        "name": "Research Disclaimer",
        "ref_cell": "C44",
        "value_col": "F",
        "column": False,
        "row_start": 44,
        "mandatory": True,
        "enum": [
            "A disclaimer must be published with research outputs",
            "No requirements",
        ],
        "datatype": str,
        "func": bov.validate_BackOffice_research_disclaimer,
    },
}
